@@ -52,12 +52,10 @@ static char sccsid[] = "@(#)ruserpass.c	8.4 (Berkeley) 4/27/95";
 #include <err.h>
 
 #include "ftp_var.h"
+#include <libinetutils.h>
+#include <xalloc.h>
 
-extern char *localhost __P((void));
-extern char *xstrdup __P((const char *));
-extern char *xmalloc __P((size_t));
-
-static	int token __P((void));
+static	int token (void);
 static	FILE *cfile;
 
 /* protect agains os headers */
