@@ -140,12 +140,12 @@ struct tab
 
 extern struct tab cmdtab[];
 extern struct tab sitetab[];
-static char *copy         __P ((char *));
-static void help          __P ((struct tab *, char *));
-static struct tab *lookup __P ((struct tab *, char *));
-static void sizecmd       __P ((char *));
-static int yylex          __P ((void));
-static void yyerror       __P ((const char *s));
+static char *copy         (char *);
+static void help          (struct tab *, char *);
+static struct tab *lookup (struct tab *, char *);
+static void sizecmd       (char *);
+static int yylex          (void);
+static void yyerror       (const char *s);
 
 
 #line 117 "ftpcmd.y"
@@ -417,7 +417,7 @@ static const short yycheck[] = {    92,
     -1,    -1,    -1,    -1,    65
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/share/bison/bison.simple"
+#line 3 "/usr/share/bison.simple"
 /* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
@@ -631,7 +631,7 @@ __yy_memcpy (char *to, char *from, unsigned int count)
 #endif
 #endif
 
-#line 217 "/usr/share/bison/bison.simple"
+#line 217 "/usr/share/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -988,7 +988,7 @@ case 6:
 {
 			usedefault = 0;
 			if (pdata >= 0) {
-				(void) close(pdata);
+				close(pdata);
 				pdata = -1;
 			}
 			if (yyvsp[-3].i) {
@@ -1295,7 +1295,7 @@ case 36:
 
 			if (yyvsp[-1].i) {
 				oldmask = umask(0);
-				(void) umask(oldmask);
+				umask(oldmask);
 				reply(200, "Current UMASK is %03o", oldmask);
 			}
 		;
@@ -1351,7 +1351,7 @@ case 40:
 					maxtimeout);
 			    } else {
 				timeout = yyvsp[-1].i;
-				(void) alarm((unsigned) timeout);
+				alarm((unsigned) timeout);
 				reply(200,
 					"Maximum IDLE time set to %d seconds",
 					timeout);
@@ -1682,7 +1682,7 @@ case 74:
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 543 "/usr/share/bison/bison.simple"
+#line 543 "/usr/share/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2021,13 +2021,13 @@ telnet_fgets(char *s, int n, FILE *iop)
 			case WONT:
 				c = getc(iop);
 				printf("%c%c%c", IAC, DONT, 0377&c);
-				(void) fflush(stdout);
+				fflush(stdout);
 				continue;
 			case DO:
 			case DONT:
 				c = getc(iop);
 				printf("%c%c%c", IAC, WONT, 0377&c);
-				(void) fflush(stdout);
+				fflush(stdout);
 				continue;
 			case IAC:
 				break;
@@ -2064,10 +2064,9 @@ telnet_fgets(char *s, int n, FILE *iop)
 	return (s);
 }
 
-void
-toolong(int signo)
+RETSIGTYPE
+toolong(int signo ARG_UNUSED)
 {
-  (void)signo;
 	reply(421,
 	    "Timeout (%d seconds): closing control connection.", timeout);
 	if (logging)
@@ -2089,13 +2088,13 @@ yylex()
 		switch (state) {
 
 		case CMD:
-			(void) signal(SIGALRM, toolong);
-			(void) alarm((unsigned) timeout);
+			signal(SIGALRM, toolong);
+			alarm((unsigned) timeout);
 			if (telnet_fgets(cbuf, sizeof(cbuf)-1, stdin) == NULL) {
 				reply(221, "You could at least say goodbye.");
 				dologout(0);
 			}
-			(void) alarm(0);
+			alarm(0);
 #ifdef HAVE_SETPROCTITLE
 			if (strncasecmp(cbuf, "PASS", 4) != NULL)
 				setproctitle("%s: %s", proctitle, cbuf);
@@ -2312,7 +2311,7 @@ copy(char *s)
 	p = malloc((unsigned) strlen(s) + 1);
 	if (p == NULL)
 		fatal("Ran out of memory.");
-	(void) strcpy(p, s);
+	strcpy(p, s);
 	return (p);
 }
 
@@ -2362,7 +2361,7 @@ help(struct tab *ctab, char *s)
 			}
 			printf("\r\n");
 		}
-		(void) fflush(stdout);
+		fflush(stdout);
 		reply(214, "Direct comments to ftp-bugs@%s.", hostname);
 		return;
 	}
@@ -2405,7 +2404,7 @@ sizecmd(char *filename)
 		}
 		if (fstat(fileno(fin), &stbuf) < 0 || !S_ISREG(stbuf.st_mode)) {
 			reply(550, "%s: not a plain file.", filename);
-			(void) fclose(fin);
+			fclose(fin);
 			return;
 		}
 
@@ -2415,7 +2414,7 @@ sizecmd(char *filename)
 				count++;
 			count++;
 		}
-		(void) fclose(fin);
+		fclose(fin);
 
 		reply(213, sizeof(count) > sizeof(long) ? "%qd" : "%ld",
 		      count);
@@ -2431,7 +2430,7 @@ yyerror(const char *s)
 {
   char *cp;
 
-  (void)s;
+  s;
   cp = strchr(cbuf,'\n');
   if (cp != NULL)
     *cp = '\0';
