@@ -1,12 +1,12 @@
 /* hpux.c -- HPUX specific code for ifconfig
 
-   Copyright (C) 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 2001, 2002, 2007 Free Software Foundation, Inc.
 
    Written by Marcus Brinkmann.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
-   as published by the Free Software Foundation; either version 2
+   as published by the Free Software Foundation; either version 3
    of the License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -145,17 +145,17 @@ system_parse_opt_rest (struct ifconfig **ifp, int argc, char *argv[])
     {
     case EXPECT_BROADCAST:
       fprintf (stderr, "%s: option `broadcast' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_NETMASK:
       fprintf (stderr, "%s: option `netmask' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_METRIC:
       fprintf (stderr, "%s: option `metric' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_NAME:
