@@ -306,7 +306,7 @@ system_fh_hwaddr (format_data_t form, int argc, char *argv[])
   if (ioctl (form->sfd, SIOCGIFHWADDR, form->ifr) < 0)
     {
       fprintf (stderr, "%s: SIOCGIFHWADDR failed for interface `%s': %s\n",
-	       __progname, form->ifr->ifr_name, strerror (errno));
+	       program_name, form->ifr->ifr_name, strerror (errno));
       exit (EXIT_FAILURE);
     }
   else
@@ -343,7 +343,7 @@ system_fh_hwtype (format_data_t form, int argc, char *argv[])
   if (ioctl (form->sfd, SIOCGIFHWADDR, form->ifr) < 0)
     {
       fprintf (stderr, "%s: SIOCGIFHWADDR failed for interface `%s': %s\n",
-	       __progname, form->ifr->ifr_name, strerror (errno));
+	       program_name, form->ifr->ifr_name, strerror (errno));
       exit (EXIT_FAILURE);
     }
   else
@@ -380,7 +380,7 @@ system_fh_txqlen (format_data_t form, int argc, char *argv[])
   if (ioctl (form->sfd, SIOCGIFTXQLEN, form->ifr) < 0)
     {
       fprintf (stderr, "%s: SIOCGIFTXQLEN failed for interface `%s': %s\n",
-	       __progname, form->ifr->ifr_name, strerror (errno));
+	       program_name, form->ifr->ifr_name, strerror (errno));
       exit (EXIT_FAILURE);
     }
   else
@@ -410,7 +410,7 @@ system_parse_opt_set_txqlen(struct ifconfig *ifp, char *arg)
   if (!ifp)
     {
       fprintf (stderr, "%s: no interface specified for txqlen"
-	       " `%s'\n", __progname, arg);
+	       " `%s'\n", program_name, arg);
       usage (EXIT_FAILURE);
     }
 
@@ -420,7 +420,7 @@ system_parse_opt_set_txqlen(struct ifconfig *ifp, char *arg)
       if (! ifp->system)
 	{
 	  fprintf (stderr, "%s: can't get memory for system interface "
-		   "configuration: %s\n", __progname, strerror (errno));
+		   "configuration: %s\n", program_name, strerror (errno));
 	  exit (EXIT_FAILURE);
 	}
       ifp->system->valid = 0;
@@ -429,7 +429,7 @@ system_parse_opt_set_txqlen(struct ifconfig *ifp, char *arg)
   if (ifp->system->valid & IF_VALID_TXQLEN)
     {
       fprintf (stderr, "%s: only one txqlen allowed for interface `%s'\n",
-	       __progname, ifp->name);
+	       program_name, ifp->name);
       usage (EXIT_FAILURE);
     }
   ifp->system->txqlen = strtol (arg, &end, 0);
@@ -437,7 +437,7 @@ system_parse_opt_set_txqlen(struct ifconfig *ifp, char *arg)
     {
       fprintf (stderr, "%s: txqlen value `%s' for interface `%s' "
 	       "is not a number.\n",
-	       __progname, arg, ifp->name);
+	       program_name, arg, ifp->name);
       exit (EXIT_FAILURE);
     }
   ifp->system->valid |= IF_VALID_TXQLEN;
@@ -531,32 +531,32 @@ system_parse_opt_rest (struct ifconfig **ifp, int argc, char *argv[])
     {
     case EXPECT_BROADCAST:
       fprintf (stderr, "%s: option `broadcast' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_DSTADDR:
       fprintf (stderr, "%s: option `pointopoint' (`dstaddr') requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_NETMASK:
       fprintf (stderr, "%s: option `netmask' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_METRIC:
       fprintf (stderr, "%s: option `metric' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_MTU:
       fprintf (stderr, "%s: option `mtu' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_TXQLEN:
       fprintf (stderr, "%s: option `txqueuelen' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_NOTHING:
@@ -576,7 +576,7 @@ system_configure (int sfd, struct ifreq *ifr, struct system_ifconfig *ifs)
     {
 #ifndef SIOCSIFTXQLEN
       printf ("%s: Don't know how to set the txqlen on this system.\n",
-	      __progname);
+	      program_name);
       return -1;
 #else
       int err = 0;
@@ -586,7 +586,7 @@ system_configure (int sfd, struct ifreq *ifr, struct system_ifconfig *ifs)
       if (err < 0)
 	{
 	  fprintf (stderr, "%s: SIOCSIFTXQLEN failed: %s\n",
-		   __progname, strerror (errno));
+		   program_name, strerror (errno));
 	  return -1;
 	}
       if (verbose)
