@@ -1,12 +1,12 @@
 /* solaris.c -- Solaris specific code for ifconfig
 
-   Copyright (C) 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 2001, 2002, 2007 Free Software Foundation, Inc.
 
    Written by Marcus Brinkmann.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
-   as published by the Free Software Foundation; either version 2
+   as published by the Free Software Foundation; either version 3
    of the License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -142,22 +142,22 @@ system_parse_opt_rest (struct ifconfig **ifp, int argc, char *argv[])
     {
     case EXPECT_BROADCAST:
       fprintf (stderr, "%s: option `broadcast' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_NETMASK:
       fprintf (stderr, "%s: option `netmask' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_METRIC:
       fprintf (stderr, "%s: option `metric' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_MTU:
       fprintf (stderr, "%s: option `mtu' requires an argument\n",
-	       __progname);
+	       program_name);
       break;
 
     case EXPECT_NOTHING:
@@ -177,7 +177,7 @@ system_configure (int sfd, struct ifreq *ifr, struct system_ifconfig *ifs)
     {
 #ifndef SIOCSIFTXQLEN
       printf ("%s: Don't know how to set the txqlen on this system.\n",
-	      __progname);
+	      program_name);
       return -1;
 #else
       int err = 0;
@@ -187,7 +187,7 @@ system_configure (int sfd, struct ifreq *ifr, struct system_ifconfig *ifs)
       if (err < 0)
 	{
 	  fprintf (stderr, "%s: SIOCSIFTXQLEN failed: %s\n",
-		   __progname, strerror (errno));
+		   program_name, strerror (errno));
 	  return -1;
 	}
       if (verbose)
