@@ -1,4 +1,5 @@
-/* Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+/* Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
 
    This file is part of GNU Inetutils.
 
@@ -155,7 +156,7 @@ static char sccsid[] = "@(#)inetd.c	8.4 (Berkeley) 4/13/94";
 #endif
 #define	SIGBLOCK	(sigmask(SIGCHLD)|sigmask(SIGHUP)|sigmask(SIGALRM))
 
-extern char *__progname;
+char *program_name;
 
 int	debug = 0;
 int	nsock, maxsock;
@@ -197,42 +198,43 @@ struct	servtab {
 #define ISMUXPLUS(sep)	((sep)->se_type == MUXPLUS_TYPE)
 
 
-void		chargen_dg __P((int, struct servtab *));
-void		chargen_stream __P((int, struct servtab *));
-void		close_sep __P((struct servtab *));
-void		config __P((int));
-void		daytime_dg __P((int, struct servtab *));
-void		daytime_stream __P((int, struct servtab *));
-void		discard_dg __P((int, struct servtab *));
-void		discard_stream __P((int, struct servtab *));
-void		echo_dg __P((int, struct servtab *));
-void		echo_stream __P((int, struct servtab *));
-void		endconfig __P((FILE *));
-struct servtab *enter __P((struct servtab *));
-void		freeconfig __P((struct servtab *));
-struct servtab *getconfigent __P((FILE *, const char *, size_t *));
-void		machtime_dg __P((int, struct servtab *));
-void		machtime_stream __P((int, struct servtab *));
-char	       *newstr __P((const char *));
-char	       *nextline __P((FILE *));
-void		nextconfig __P((const char *));
-void		print_service __P((const char *, const char *, struct servtab *));
-void		reapchild __P((int));
-void		retry __P((int));
-FILE           *setconfig __P((const char *));
-void		setup __P((struct servtab *));
-void		tcpmux __P((int s, struct servtab *sep));
-void		set_proc_title __P ((char *, int));
-void		initring __P((void));
-long		machtime __P((void));
-void            run_service __P ((int ctrl, struct servtab *sep));
+void		chargen_dg (int, struct servtab *);
+void		chargen_stream (int, struct servtab *);
+void		close_sep (struct servtab *);
+void		config (int);
+void		daytime_dg (int, struct servtab *);
+void		daytime_stream (int, struct servtab *);
+void		discard_dg (int, struct servtab *);
+void		discard_stream (int, struct servtab *);
+void		echo_dg (int, struct servtab *);
+void		echo_stream (int, struct servtab *);
+void		endconfig (FILE *);
+struct servtab *enter (struct servtab *);
+void		freeconfig (struct servtab *);
+struct servtab *getconfigent (FILE *, const char *, size_t *);
+void		machtime_dg (int, struct servtab *);
+void		machtime_stream (int, struct servtab *);
+char	       *newstr (const char *);
+char	       *nextline (FILE *);
+void		nextconfig (const char *);
+void		print_service (const char *, const char *, struct servtab *);
+void		reapchild (int);
+void		retry (int);
+FILE           *setconfig (const char *);
+void		setup (struct servtab *);
+void		tcpmux (int s, struct servtab *sep);
+void		set_proc_title (char *, int);
+void		initring (void);
+long		machtime (void);
+void            run_service (int ctrl, struct servtab *sep);
+void            prepenv (int ctrl, struct sockaddr_in sa_client);
 
 struct biltin {
   const char	*bi_service;	/* internally provided service name */
   int	bi_socktype;		/* type of socket supported */
   short	bi_fork;		/* 1 if should fork before call */
   short	bi_wait;		/* 1 if should wait for child */
-  void	(*bi_fn) __P((int s, struct servtab *)); /*function which performs it */
+  void	(*bi_fn) (int s, struct servtab *); /*function which performs it */
 } biltins[] = {
   /* Echo received data */
   { "echo",	SOCK_STREAM,	1, 0,	echo_stream },
@@ -270,8 +272,12 @@ char **config_files;
 
 #if defined(HAVE_SIGACTION)
 # define SIGSTATUS sigset_t
+# define sigstatus_empty(s) sigemptyset(&s)
+# define inetd_pause(s) sigsuspend(&s)
 #else
 # define SIGSTATUS long
+# define sigstatus_empty(s) s = 0
+# define inetd_pause(s) sigpause (s)
 #endif
 
 void
@@ -340,16 +346,20 @@ usage (int err)
   if (err != 0)
     {
       fprintf (stderr, "Usage: %s [OPTION...] [CONF-FILE [CONF-DIR]] ...\n",
-	       __progname);
-      fprintf (stderr, "Try `%s --help' for more information.\n", __progname);
+	       program_name);
+      fprintf (stderr, "Try `%s --help' for more information.\n", program_name);
     }
   else
     {
       fprintf (stdout, "Usage: %s [OPTION...] [CONF-FILE [CONF-DIR]] ...\n",
-	       __progname);
+	       program_name);
       puts ("Internet super-server.\n\n\
   -d, --debug               Debug mode\n\
+      --environment         Pass local and remote socket information in\n\
+                            environment variables\n\
   -R, --rate NUMBER         Maximum invocation rate (per second)\n\
+      --resolve             Resolve IP addresses when setting environment\n\
+                            variables (see --environment)\n\
       --help                Display this help and exit\n\
   -V, --version             Output version information and exit");
 
@@ -358,6 +368,9 @@ usage (int err)
   exit (err);
 }
 
+static int env_option;      /* Set environment variables */
+static int resolve_option;  /* Resolve IP addresses */
+
 static const char *short_options = "dR:V";
 static struct option long_options[] =
 {
@@ -365,6 +378,8 @@ static struct option long_options[] =
   { "rate", required_argument, 0, 'R' },
   { "help", no_argument, 0, '&' },
   { "version", no_argument, 0, 'V' },
+  { "resolve", no_argument, &resolve_option, 1 },
+  { "environment", no_argument, &env_option, 1 },
   { 0, 0, 0, 0 }
 };
 
@@ -376,9 +391,7 @@ main (int argc, char *argv[], char *envp[])
   int dofork;
   pid_t pid;
 
-#ifndef HAVE___PROGNAME
-  __progname = argv[0];
-#endif
+  program_name = argv[0];
 
   Argv = argv;
   if (envp == 0 || *envp == 0)
@@ -420,6 +433,9 @@ main (int argc, char *argv[], char *envp[])
 	  exit (0);
 	  /* Not reached.  */
 
+	case 0:
+	  break;
+	  
 	case '?':
 	default:
 	  usage (1);
@@ -427,6 +443,9 @@ main (int argc, char *argv[], char *envp[])
 	}
     }
 
+  if (resolve_option)
+    env_option = 1;
+  
   if (optind < argc)
     {
       int i;
@@ -458,7 +477,8 @@ main (int argc, char *argv[], char *envp[])
         fclose (fp);
       }
     else
-      syslog (LOG_CRIT, "can't open %s: %s\n", PATH_INETDPID, strerror (errno));
+      syslog (LOG_CRIT, "can't open %s: %s\n", PATH_INETDPID,
+	      strerror (errno));
   }
 
   signal_set_handler (SIGALRM, retry);
@@ -484,9 +504,12 @@ main (int argc, char *argv[], char *envp[])
 
       if (nsock == 0)
 	{
+	  SIGSTATUS stat;
+	  sigstatus_empty (stat);
+	  
 	  signal_block (NULL);
 	  while (nsock == 0)
-	    sigpause (0L);
+	    inetd_pause (stat);
 	  signal_unblock (NULL);
 	}
       readable = allsock;
@@ -505,7 +528,11 @@ main (int argc, char *argv[], char *envp[])
 	      fprintf (stderr, "someone wants %s\n", sep->se_service);
 	    if (!sep->se_wait && sep->se_socktype == SOCK_STREAM)
 	      {
-		ctrl = accept (sep->se_fd, NULL, NULL);
+		struct sockaddr_in sa_client;
+		socklen_t len = sizeof (sa_client);
+		
+		ctrl = accept (sep->se_fd, (struct sockaddr *)&sa_client,
+			       &len);
 		if (debug)
 		  fprintf (stderr, "accept, ctrl %d\n", ctrl);
 		if (ctrl < 0)
@@ -515,6 +542,8 @@ main (int argc, char *argv[], char *envp[])
 			      sep->se_service);
 		    continue;
 		  }
+		if (env_option)
+		  prepenv (ctrl, sa_client);
 	      }
 	    else
 	      ctrl = sep->se_fd;
@@ -812,14 +841,26 @@ nextconfig (const char *file)
 	  sep->se_fd = -1;
 	  continue;
 	}
-#ifndef IPV6 /* This code is moved to setup() for IPV6.  */
+#ifndef IPV6 /* FIXME: This code is moved to setup() for IPV6, which is
+	        wrong */
       sp = getservbyname (sep->se_service, sep->se_proto);
       if (sp == 0)
 	{
-	  syslog (LOG_ERR, "%s/%s: unknown service",
-		  sep->se_service, sep->se_proto);
-	  sep->se_checked = 0;
-	  continue;
+	  static struct servent servent;
+	  char *p;
+	  unsigned long val;
+	  unsigned short port;
+
+	  val = strtoul (sep->se_service, &p, 0);
+	  if (*p || (port = val) != val)
+	    {
+	      syslog (LOG_ERR, "%s/%s: unknown service",
+		      sep->se_service, sep->se_proto);
+	      sep->se_checked = 0;
+	      continue;
+	    }
+	  servent.s_port = htons (port);
+	  sp = &servent;
 	}
       if (sp->s_port != sep->se_ctrladdr.sin_port)
 	{
@@ -1703,3 +1744,71 @@ tcpmux(int s, struct servtab *sep)
   strwrite (s, "-Service not available\r\n");
   exit (1);
 }
+
+/* Set TCP environment variables, modelled after djb's ucspi-tcp tools:
+   http://cr.yp.to/ucspi-tcp/environment.html
+   FIXME: This needs support for IPv6
+*/
+void
+prepenv (int ctrl, struct sockaddr_in sa_client)
+{
+  char str[16];
+  char *ip;
+  struct hostent *host;
+  struct sockaddr_in sa_server;
+  socklen_t len = sizeof (sa_server);
+
+  setenv ("PROTO", "TCP", 1);
+  unsetenv ("TCPLOCALIP");
+  unsetenv ("TCPLOCALHOST");
+  unsetenv ("TCPLOCALPORT");
+  unsetenv ("TCPREMOTEIP");
+  unsetenv ("TCPREMOTEPORT");
+  unsetenv ("TCPREMOTEHOST");
+  
+  if (getsockname (ctrl, (struct sockaddr*)&sa_server, &len) < 0)
+    syslog (LOG_WARNING, "getsockname(): %m");
+  else
+    {
+      ip = inet_ntoa (sa_server.sin_addr);
+      if (ip)
+	{
+	  if (setenv ("TCPLOCALIP", ip, 1) < 0)
+	    syslog (LOG_WARNING, "setenv (TCPLOCALIP): %m");
+	}
+
+      snprintf (str, sizeof (str), "%d", ntohs (sa_server.sin_port));
+      setenv ("TCPLOCALPORT", str, 1);
+
+      if (resolve_option)
+	{
+	  if ((host = gethostbyaddr((char *) &sa_server.sin_addr,
+				    sizeof (sa_server.sin_addr),
+				    AF_INET)) == NULL)
+	    syslog (LOG_WARNING, "gethostbyaddr: %m");
+	  else if (setenv ("TCPLOCALHOST", host->h_name, 1) < 0)
+	    syslog (LOG_WARNING, "setenv(TCPLOCALHOST): %m");
+	}
+    }
+
+  ip = inet_ntoa (sa_client.sin_addr);
+  if (ip)
+    {
+      if (setenv ("TCPREMOTEIP", ip, 1) < 0)
+	syslog (LOG_WARNING, "setenv(TCPREMOTEIP): %m");
+    }
+
+  snprintf (str, sizeof (str), "%d", ntohs (sa_client.sin_port));
+  if (setenv ("TCPREMOTEPORT", str, 1) < 0)
+    syslog (LOG_WARNING, "setenv(TCPREMOTEPORT): %m");
+
+  if (resolve_option)
+    {
+      if ((host = gethostbyaddr ((char *) &sa_client.sin_addr,
+				 sizeof (sa_client.sin_addr),
+				 AF_INET)) == NULL)
+	syslog (LOG_WARNING, "gethostbyaddr: %m");
+      else if (setenv ("TCPREMOTEHOST", host->h_name, 1) < 0)
+	syslog (LOG_WARNING, "setenv(TCPREMOTEHOST): %m");
+    }
+}
