@@ -1,10 +1,10 @@
-/* Copyright (C) 1998, 2001, 2002, 2004, 2005 Free Software Foundation, Inc.
+/* Copyright (C) 1998, 2001, 2002, 2004, 2005, 2007 Free Software Foundation, Inc.
 
    This file is part of GNU Inetutils.
 
    GNU Inetutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Inetutils is distributed in the hope that it will be useful,
@@ -76,6 +76,8 @@ static int ping_echo (int argc, char **argv);
 static void show_usage (void);
 static int send_echo (PING *ping);
 
+char *program_name;
+
 int
 main (int argc, char **argv)
 {
@@ -87,6 +89,7 @@ main (int argc, char **argv)
   u_char *patptr = NULL;
   int is_root = getuid () == 0;
 
+  program_name = argv[0];
   if ((ping = ping_init (0, getpid ())) == NULL)
     {
       fprintf (stderr, "can't init ping: %s\n", strerror (errno));
