@@ -1,10 +1,10 @@
-/* Copyright (C) 1998, 2001, 2002, 2004, 2005 Free Software Foundation, Inc.
+/* Copyright (C) 1998, 2001, 2002, 2004, 2005, 2007 Free Software Foundation, Inc.
 
    This file is part of GNU Inetutils.
 
    GNU Inetutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Inetutils is distributed in the hope that it will be useful,
@@ -21,6 +21,8 @@
 # include <config.h>
 #endif
 
+#include <sys/types.h>
+#include <sys/time.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <xalloc.h>
@@ -146,7 +148,7 @@ show_license (void)
   static char license_text[] =
 "   This program is free software; you can redistribute it and/or modify\n"
 "   it under the terms of the GNU General Public License as published by\n"
-"   the Free Software Foundation; either version 2, or (at your option)\n"
+"   the Free Software Foundation; either version 3, or (at your option)\n"
 "   any later version.\n"
 "\n"
 "   This program is distributed in the hope that it will be useful,\n"
