@@ -1,10 +1,10 @@
-/* Copyright (C) 2001, 2002 Free Software Foundation, Inc.
+/* Copyright (C) 2001, 2002, 2004, 2007 Free Software Foundation, Inc.
 
    This file is part of GNU Inetutils.
 
    GNU Inetutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Inetutils is distributed in the hope that it will be useful,
@@ -13,9 +13,9 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Inetutils; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA. */
+   along with GNU Inetutils; see the file COPYING.  If not, write
+   to the Free Software Foundation, Inc., 51 Franklin Street,
+   Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -45,18 +45,17 @@
 #include <errno.h>
 #include <limits.h>
 
-#include "getopt.h"
 #include <icmp.h>
 #include <ping.h>
-#include <ping_impl.h>
+#include "ping_common.h"
+#include "ping_impl.h"
 
 #define	NROUTES		9		/* number of record route slots */
 #ifndef MAX_IPOPTLEN
 # define MAX_IPOPTLEN 40
 #endif
 
-extern char *xstrdup (const char *);
-extern char *xmalloc (size_t);
+#include <xalloc.h>
 
 static int handler (int code, void *closure,
 		   struct sockaddr_in *dest, struct sockaddr_in *from,
@@ -70,8 +69,6 @@ void print_icmp_header (struct sockaddr_in *from,
 			      struct ip *ip, icmphdr_t *icmp, int len);
 static void print_ip_opt (struct ip *ip, int hlen);
 
-static void tvsub (struct timeval *out, struct timeval *in);
-
 int
 ping_echo (int argc, char **argv)
 {
@@ -526,48 +523,6 @@ print_ip_opt (struct ip *ip, int hlen)
       }
 }
 
-/*
- * tvsub --
- *	Subtract 2 timeval structs:  out = out - in.  Out is assumed to
- * be >= in.
- */
-static void
-tvsub (struct timeval *out, struct timeval *in)
-{
-  if ((out->tv_usec -= in->tv_usec) < 0)
-    {
-      --out->tv_sec;
-      out->tv_usec += 1000000;
-    }
-  out->tv_sec -= in->tv_sec;
-}
-
-double
-nabs (double a)
-{
-  return (a < 0) ? -a : a;
-}
-
-double
-nsqrt (double a, double prec)
-{
-  double x0, x1;
-  
-  if (a < 0)
-    return 0; 
-  if (a < prec)
-    return 0;
-  x1 = a/2;
-  do
-    {
-      x0 = x1;
-      x1 = (x0 + a/x0) / 2;
-    }
-  while (nabs (x1 - x0) > prec);
-
-  return x1;
-}
-
 int
 echo_finish ()
 {
