@@ -100,7 +100,8 @@ okname(char *cp0)
 	} while (*++cp);
 	return (1);
 
-bad:	warnx("%s: invalid user name", cp0);
+bad:	
+	error (0, 0, "%s: invalid user name", cp0);
 	return (0);
 }
 
@@ -143,7 +144,7 @@ allocbuf(BUF *bp, int fd, int blksize)
 #ifndef roundup
 #  define roundup(x, y)   ((((x)+((y)-1))/(y))*(y))
 #endif
-	size = roundup(ST_BLKSIZE(stb), blksize);
+	size = roundup(BUFSIZ, blksize);
 	if (size == 0)
 		size = blksize;
 	if (bp->cnt >= size)
@@ -157,10 +158,10 @@ allocbuf(BUF *bp, int fd, int blksize)
 	return (bp);
 }
 
-void
+RETSIGTYPE
 lostconn(int signo)
 {
 	if (!iamremote)
-		warnx("lost connection");
+		error (0, 0, "lost connection");
 	exit(1);
 }
