@@ -98,18 +98,20 @@ char *alloca ();
 # include <sys/select.h>
 #endif
 
+#include <libinetutils.h>
+
 int	keepalive = 1;		/* flag for SO_KEEPALIVE scoket option */
 int	check_all;
 int	log_success;		/* If TRUE, log all successful accesses */
 int	sent_null;
 
-void	 doit __P ((int, struct sockaddr_in *));
-void	 rshd_error __P ((const char *, ...));
-char	*getstr __P ((const char *));
-int	 local_domain __P ((const char *));
-const char *topdomain __P ((const char *));
-void	 usage __P ((void));
-void     help __P ((void));
+void	 doit (int, struct sockaddr_in *);
+void	 rshd_error (const char *, ...);
+char	*getstr (const char *);
+int	 local_domain (const char *);
+const char *topdomain (const char *);
+void	 usage (void);
+void     help (void);
 
 #if defined(KERBEROS) || defined(SHISHI)
 #ifdef KERBEROS
@@ -150,6 +152,8 @@ static struct option long_options[] =
   {0, 0, 0, 0}
 };
 
+char *program_name;
+
 /* Remote shell server. We're invoked by the rcmd(3) function. */
 int
 main (int argc, char *argv[])
@@ -160,6 +164,7 @@ main (int argc, char *argv[])
   struct sockaddr_in from;
   int sockfd;
 
+  program_name = argv[0];
   opterr = 0;
   while ((ch = getopt_long (argc, argv, short_options, long_options, NULL))
 	 != EOF)
@@ -463,8 +468,8 @@ doit (int sockfd, struct sockaddr_in *fromp)
       dup2 (sockfd, STDERR_FILENO);
     }
 
-  /* Get the "name" of the clent form its Internet address.
-   * This is used for the autentication below
+  /* Get the "name" of the client from its Internet address.  This is
+   * used for the authentication below.
    */
   errorstr = NULL;
   hp = gethostbyaddr((char *)&fromp->sin_addr, sizeof (struct in_addr),
@@ -1187,7 +1192,6 @@ getstr(const char *err)
 int
 local_domain (const char *h)
 {
-  extern char *localhost __P ((void));
   char *hostname = localhost ();
 
   if (! hostname)
