@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -55,15 +51,15 @@ static char sccsid[] = "@(#)ctl.c	8.1 (Berkeley) 6/6/93";
 #include "talk.h"
 #include "talk_ctl.h"
 
-#ifdef HAVE_SOCKADDR_IN_SIN_LEN
+#ifdef HAVE_STRUCT_SOCKADDR_IN_SIN_LEN
 struct	sockaddr_in daemon_addr = { sizeof(daemon_addr), AF_INET };
 struct	sockaddr_in ctl_addr = { sizeof(ctl_addr), AF_INET };
 struct	sockaddr_in my_addr = { sizeof(my_addr), AF_INET };
-#else /* !HAVE_SOCKADDR_IN_SIN_LEN */
+#else /* !HAVE_STRUCT_SOCKADDR_IN_SIN_LEN */
 struct	sockaddr_in daemon_addr = { AF_INET };
 struct	sockaddr_in ctl_addr = { AF_INET };
 struct	sockaddr_in my_addr = { AF_INET };
-#endif /* HAVE_SOCKADDR_IN_SIN_LEN */
+#endif /* HAVE_STRUCT_SOCKADDR_IN_SIN_LEN */
 
 	/* inet addresses of the two machines */
 struct	in_addr my_machine_addr;
@@ -77,6 +73,7 @@ int	invitation_waiting = 0;
 
 CTL_MSG msg;
 
+int
 open_sockt()
 {
 	int length;
@@ -94,7 +91,8 @@ open_sockt()
 }
 
 /* open the ctl socket */
-open_ctl() 
+int
+open_ctl()
 {
 	int length;
 
@@ -113,6 +111,7 @@ open_ctl()
 }
 
 /* print_addr is a debug print routine */
+int
 print_addr(addr)
 	struct sockaddr_in addr;
 {
