@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -35,7 +31,7 @@
 static char sccsid[] = "@(#)msgs.c	8.1 (Berkeley) 6/6/93";
 #endif /* not lint */
 
-/* 
+/*
  * A package to display what is happening every MSG_INTERVAL seconds
  * if we are slow connecting.
  */
@@ -64,12 +60,12 @@ char	*current_state;
 int	current_line = 0;
 
 void
-disp_msg(sig)
-  int sig;
+disp_msg(int sig)
 {
 	message(current_state);
 }
 
+int
 start_msgs()
 {
 	struct itimerval itimer;
@@ -81,6 +77,7 @@ start_msgs()
 	setitimer(ITIMER_REAL, &itimer, (struct itimerval *)0);
 }
 
+int
 end_msgs()
 {
 	struct itimerval itimer;
