@@ -1,10 +1,10 @@
-/* Copyright (C) 1998,2001 Free Software Foundation, Inc.
+/* Copyright (C) 1998,2001,2007 Free Software Foundation, Inc.
 
    This file is part of GNU Inetutils.
 
    GNU Inetutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Inetutils is distributed in the hope that it will be useful,
@@ -13,9 +13,9 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Inetutils; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA. */
+   along with GNU Inetutils; see the file COPYING.  If not, write
+   to the Free Software Foundation, Inc., 51 Franklin Street,
+   Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #include <intalkd.h>
 
@@ -87,9 +87,8 @@ lookup_request (CTL_MSG *request, int (*comp)(table_t *, CTL_MSG *, time_t *))
 }
 
 static int
-fuzzy_comp (table_t *ptr, CTL_MSG *request, time_t *unused)
+fuzzy_comp (table_t *ptr, CTL_MSG *request, time_t *unused ARG_UNUSED)
 {
-  (void)unused;
   if (ptr->request.type == LEAVE_INVITE
       && strcmp(request->l_name, ptr->request.r_name) == 0
       && strcmp(request->r_name, ptr->request.l_name) == 0)
