@@ -20,6 +20,7 @@
 #include <intalkd.h>
 #include <signal.h>
 #include <getopt.h>
+#include <libinetutils.h>
 
 #ifndef LOG_FACILITY
 # define LOG_FACILITY LOG_DAEMON
@@ -53,6 +54,7 @@ time_t max_idle_time = 120;
 time_t max_request_ttl = MAX_LIFE;
 
 char *hostname;
+char *program_name;
 
 int
 main(int argc, char *argv[])
@@ -60,6 +62,8 @@ main(int argc, char *argv[])
   int c;
   char *acl_file = NULL;
 
+  program_name = argv[0];
+  
   while ((c = getopt_long (argc, argv, short_options, long_options, NULL))
 	 != EOF)
     {
@@ -114,7 +118,6 @@ main(int argc, char *argv[])
 void
 talkd_init ()
 {
-  extern char * localhost(void);
   openlog ("talkd", LOG_PID, LOG_FACILITY);
   hostname = localhost ();
   if (!hostname)
