@@ -22,6 +22,7 @@
 #ifdef HAVE_SYS_UTSNAME_H
 # include <sys/utsname.h>
 #endif
+#include <libinetutils.h>
 
 static char short_options[] = "a:D::d:E:HhLl::nS:Uu:VX:";
 
@@ -106,11 +107,13 @@ char	*terminaltype;
 
 int	SYNCHing;		/* we are in TELNET SYNCH mode */
 struct telnetd_clocks clocks;
+char *program_name;
 
 int
 main (int argc, char **argv)
 {
   int c;
+  program_name = argv[0];
   while ((c = getopt_long (argc, argv, short_options, long_options, NULL))
 	 != EOF)
     {
@@ -270,8 +273,6 @@ parse_debug_level (char *str)
 
 typedef unsigned int ip_addr_t; /*FIXME*/
 
-extern char *localhost __P ((void));
-
 void
 telnetd_setup (int fd)
 {
