@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -35,10 +31,6 @@
 static char sccsid[] = "@(#)termstat.c	8.2 (Berkeley) 5/30/95";
 #endif /* not lint */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "telnetd.h"
 
 /*
@@ -48,15 +40,12 @@ int def_tspeed = -1, def_rspeed = -1;
 #ifdef	TIOCSWINSZ
 int def_row = 0, def_col = 0;
 #endif
-#ifdef	LINEMODE
 static int _terminit = 0;
-#endif	/* LINEMODE */
 
 #if	defined(CRAY2) && defined(UNICOS5)
 int	newmap = 1;	/* nonzero if \n maps to ^M^J */
 #endif
 
-#ifdef	LINEMODE
 /*
  * localstat
  *
@@ -133,7 +122,7 @@ int	newmap = 1;	/* nonzero if \n maps to ^M^J */
  *	   then linemode is off, if server won't SGA, then linemode
  *	   is on.
  */
-	void
+void
 localstat()
 {
 	void netflush();
@@ -228,10 +217,8 @@ localstat()
 			send_wont(TELOPT_ECHO, 1);
 		else
 			need_will_echo = 1;
-#ifdef	KLUDGELINEMODE
 		if (lmodetype == KLUDGE_OK)
 			lmodetype = KLUDGE_LINEMODE;
-#endif
 	}
 
 	/*
@@ -239,26 +226,20 @@ localstat()
 	 * command and then we're all done.
 	 */
 	 if (!uselinemode && linemode) {
-# ifdef	KLUDGELINEMODE
 		if (lmodetype == REAL_LINEMODE) {
-# endif	/* KLUDGELINEMODE */
 			send_dont(TELOPT_LINEMODE, 1);
-# ifdef	KLUDGELINEMODE
 		} else if (lmodetype == KLUDGE_LINEMODE)
 			send_will(TELOPT_SGA, 1);
-# endif	/* KLUDGELINEMODE */
 		send_will(TELOPT_ECHO, 1);
 		linemode = uselinemode;
 		goto done;
 	}
 
-# ifdef	KLUDGELINEMODE
 	/*
 	 * If using real linemode check edit modes for possible later use.
 	 * If we are in kludge linemode, do the SGA negotiation.
 	 */
 	if (lmodetype == REAL_LINEMODE) {
-# endif	/* KLUDGELINEMODE */
 		useeditmode = 0;
 		if (tty_isediting())
 			useeditmode |= MODE_EDIT;
@@ -268,47 +249,38 @@ localstat()
 			useeditmode |= MODE_SOFT_TAB;
 		if (tty_islitecho())
 			useeditmode |= MODE_LIT_ECHO;
-# ifdef	KLUDGELINEMODE
 	} else if (lmodetype == KLUDGE_LINEMODE) {
 		if (tty_isediting() && uselinemode)
 			send_wont(TELOPT_SGA, 1);
 		else
 			send_will(TELOPT_SGA, 1);
 	}
-# endif	/* KLUDGELINEMODE */
 
 	/*
 	 * Negotiate linemode on if pty state has changed to turn it on.
 	 * Send appropriate command and send along edit mode, then all done.
 	 */
 	if (uselinemode && !linemode) {
-# ifdef	KLUDGELINEMODE
 		if (lmodetype == KLUDGE_LINEMODE) {
 			send_wont(TELOPT_SGA, 1);
 		} else if (lmodetype == REAL_LINEMODE) {
-# endif	/* KLUDGELINEMODE */
 			send_do(TELOPT_LINEMODE, 1);
 			/* send along edit modes */
-			(void) sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC, SB,
+			net_output_data("%c%c%c%c%c%c%c", IAC, SB,
 				TELOPT_LINEMODE, LM_MODE, useeditmode,
 				IAC, SE);
-			nfrontp += 7;
 			editmode = useeditmode;
-# ifdef	KLUDGELINEMODE
 		}
-# endif	/* KLUDGELINEMODE */
 		linemode = uselinemode;
 		goto done;
 	}
 
-# ifdef	KLUDGELINEMODE
 	/*
 	 * None of what follows is of any value if not using
 	 * real linemode.
 	 */
 	if (lmodetype < REAL_LINEMODE)
 		goto done;
-# endif	/* KLUDGELINEMODE */
 
 	if (linemode && his_state_is_will(TELOPT_LINEMODE)) {
 		/*
@@ -318,13 +290,12 @@ localstat()
 			/*
 			 * Send along appropriate edit mode mask.
 			 */
-			(void) sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC, SB,
+			net_output_data("%c%c%c%c%c%c%c", IAC, SB,
 				TELOPT_LINEMODE, LM_MODE, useeditmode,
 				IAC, SE);
-			nfrontp += 7;
 			editmode = useeditmode;
 		}
-							
+
 
 		/*
 		 * Check for changes to special characters in use.
@@ -352,33 +323,30 @@ done:
 	return;
 
 }  /* end of localstat */
-#endif	/* LINEMODE */
 
 /*
  * flowstat
  *
  * Check for changes to flow control
  */
-	void
+void
 flowstat()
 {
 	if (his_state_is_will(TELOPT_LFLOW)) {
 		if (tty_flowmode() != flowmode) {
 			flowmode = tty_flowmode();
-			(void) sprintf(nfrontp, "%c%c%c%c%c%c",
+			net_output_data ("%c%c%c%c%c%c",
 					IAC, SB, TELOPT_LFLOW,
 					flowmode ? LFLOW_ON : LFLOW_OFF,
 					IAC, SE);
-			nfrontp += 6;
 		}
 		if (tty_restartany() != restartany) {
 			restartany = tty_restartany();
-			(void) sprintf(nfrontp, "%c%c%c%c%c%c",
+			net_output_data ("%c%c%c%c%c%c",
 					IAC, SB, TELOPT_LFLOW,
 					restartany ? LFLOW_RESTART_ANY
 						   : LFLOW_RESTART_XON,
 					IAC, SE);
-			nfrontp += 6;
 		}
 	}
 }
@@ -391,9 +359,8 @@ flowstat()
  * at a time, and if using kludge linemode, then only linemode may be
  * affected.
  */
-	void
-clientstat(code, parm1, parm2)
-	register int code, parm1, parm2;
+void
+clientstat(register int code, register int parm1, register int parm2)
 {
 	void netflush();
 
@@ -406,7 +373,6 @@ clientstat(code, parm1, parm2)
 	 * Process request from client. code tells what it is.
 	 */
 	switch (code) {
-#ifdef	LINEMODE
 	case TELOPT_LINEMODE:
 		/*
 		 * Don't do anything unless client is asking us to change
@@ -414,7 +380,6 @@ clientstat(code, parm1, parm2)
 		 */
 		uselinemode = (parm1 == WILL);
 		if (uselinemode != linemode) {
-# ifdef	KLUDGELINEMODE
 			/*
 			 * If using kludge linemode, make sure that
 			 * we can do what the client asks.
@@ -426,7 +391,7 @@ clientstat(code, parm1, parm2)
 					uselinemode = 1;
 				}
 			}
-		
+
 			/*
 			 * Quit now if we can't do it.
 			 */
@@ -438,9 +403,7 @@ clientstat(code, parm1, parm2)
 			 * turned on, send along the edit mode mask.
 			 */
 			if (lmodetype == REAL_LINEMODE && uselinemode)
-# else	/* KLUDGELINEMODE */
 			if (uselinemode)
-# endif	/* KLUDGELINEMODE */
 			{
 				useeditmode = 0;
 				if (tty_isediting())
@@ -451,10 +414,9 @@ clientstat(code, parm1, parm2)
 					useeditmode |= MODE_SOFT_TAB;
 				if (tty_islitecho())
 					useeditmode |= MODE_LIT_ECHO;
-				(void) sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC,
+				net_output_data ("%c%c%c%c%c%c%c", IAC,
 					SB, TELOPT_LINEMODE, LM_MODE,
 							useeditmode, IAC, SE);
-				nfrontp += 7;
 				editmode = useeditmode;
 			}
 
@@ -467,7 +429,7 @@ clientstat(code, parm1, parm2)
 				send_will(TELOPT_ECHO, 1);
 		}
 		break;
-	
+
 	case LM_MODE:
 	    {
 		register int ack, changed;
@@ -510,20 +472,18 @@ clientstat(code, parm1, parm2)
 			set_termbuf();
 
  			if (!ack) {
- 				(void) sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC,
+ 				net_output_data ("%c%c%c%c%c%c%c", IAC,
 					SB, TELOPT_LINEMODE, LM_MODE,
  					useeditmode|MODE_ACK,
  					IAC, SE);
- 				nfrontp += 7;
  			}
- 		
+
 			editmode = useeditmode;
 		}
 
 		break;
 
 	    }  /* end of case LM_MODE */
-#endif	/* LINEMODE */
 
 	case TELOPT_NAWS:
 #ifdef	TIOCSWINSZ
@@ -532,14 +492,12 @@ clientstat(code, parm1, parm2)
 
 		def_col = parm1;
 		def_row = parm2;
-#ifdef	LINEMODE
 		/*
 		 * Defer changing window size until after terminal is
 		 * initialized.
 		 */
 		if (terminit() == 0)
 			return;
-#endif	/* LINEMODE */
 
 		/*
 		 * Change window size as requested by client.
@@ -550,20 +508,18 @@ clientstat(code, parm1, parm2)
 		(void) ioctl(pty, TIOCSWINSZ, (char *)&ws);
 	    }
 #endif	/* TIOCSWINSZ */
-		
+
 		break;
-	
+
 	case TELOPT_TSPEED:
 	    {
 		def_tspeed = parm1;
 		def_rspeed = parm2;
-#ifdef	LINEMODE
 		/*
 		 * Defer changing the terminal speed.
 		 */
 		if (terminit() == 0)
 			return;
-#endif	/* LINEMODE */
 		/*
 		 * Change terminal speed as requested by client.
 		 * We set the receive speed first, so that if we can't
@@ -595,13 +551,13 @@ clientstat(code, parm1, parm2)
 }  /* end of clientstat */
 
 #if	defined(CRAY2) && defined(UNICOS5)
-	void
+void
 termstat()
 {
 	needtermstat = 1;
 }
 
-	void
+void
 _termstat()
 {
 	needtermstat = 0;
@@ -611,16 +567,15 @@ _termstat()
 }
 #endif	/* defined(CRAY2) && defined(UNICOS5) */
 
-#ifdef	LINEMODE
 /*
  * defer_terminit
  *
  * Some things should not be done until after the login process has started
  * and all the pty modes are set to what they are supposed to be.  This
- * function is called when the pty state has been processed for the first time. 
+ * function is called when the pty state has been processed for the first time.
  * It calls other functions that do things that were deferred in each module.
  */
-	void
+void
 defer_terminit()
 {
 
@@ -655,10 +610,9 @@ defer_terminit()
  *
  * Returns true if the pty state has been processed yet.
  */
-	int
+int
 terminit()
 {
 	return(_terminit);
 
 }  /* end of terminit */
-#endif	/* LINEMODE */
